@@ -237,6 +237,9 @@ public class RaftStateMachine extends StateMachineAdapter {
                     SeataClusterContext.unbindGroup();
                 }
             });
+            Configuration conf = RouteTable.getInstance().getConfiguration(group);
+            // A member change might trigger a leader re-election. At this point, it’s necessary to filter out non-existent members and synchronize again.
+            changePeers(conf);
         }
     }
 
@@ -262,28 +265,40 @@ public class RaftStateMachine extends StateMachineAdapter {
     public void onConfigurationCommitted(Configuration conf) {
         LOGGER.info("groupId: {}, onConfigurationCommitted: {}.", group, conf);
         RouteTable.getInstance().updateConfiguration(group, conf);
+        // After a member change, the metadata needs to be synchronized again.
+        initSync.compareAndSet(true, false);
         if (isLeader()) {
-            lock.lock();
-            try {
-                List<PeerId> newFollowers = conf.getPeers();
-                Set<PeerId> newLearners = conf.getLearners();
-                List<Node> currentFollowers = raftClusterMetadata.getFollowers();
-                if (CollectionUtils.isNotEmpty(newFollowers)) {
-                    raftClusterMetadata.setFollowers(currentFollowers.stream()
-                        .filter(node -> contains(node, newFollowers)).collect(Collectors.toList()));
-                }
-                if (CollectionUtils.isNotEmpty(newLearners)) {
-                    raftClusterMetadata.setLearner(raftClusterMetadata.getLearner().stream()
-                        .filter(node -> contains(node, newLearners)).collect(Collectors.toList()));
-                }
-                syncMetadata();
-            } finally {
-                lock.unlock();
+            changePeers(conf);
+        }
+    }
+
+    private void changePeers(Configuration conf) {
+        lock.lock();
+        try {
+            List<PeerId> newFollowers = conf.getPeers();
+            Set<PeerId> newLearners = conf.getLearners();
+            List<Node> currentFollowers = raftClusterMetadata.getFollowers();
+            if (CollectionUtils.isNotEmpty(newFollowers)) {
+                raftClusterMetadata.setFollowers(currentFollowers.stream().filter(node -> contains(node, newFollowers))
+                    .collect(Collectors.toList()));
             }
+            if (CollectionUtils.isNotEmpty(newLearners)) {
+                raftClusterMetadata.setLearner(raftClusterMetadata.getLearner().stream()
+                    .filter(node -> contains(node, newLearners)).collect(Collectors.toList()));
+            } else {
+                raftClusterMetadata.setLearner(Collections.emptyList());
+            }
+            CompletableFuture.runAsync(this::syncMetadata, RESYNC_METADATA_POOL);
+        } finally {
+            lock.unlock();
         }
     }
 
     private boolean contains(Node node, Collection<PeerId> list) {
+        // This indicates that the node is of a lower version.
+        // When scaling up or down on a higher version
+        // you need to ensure that the cluster is consistent first
+        // otherwise, the lower version nodes may be removed.
         if (node.getInternal() == null) {
             return true;
         }
@@ -367,17 +382,16 @@ public class RaftStateMachine extends StateMachineAdapter {
     }
 
     private void syncCurrentNodeInfo(String group) {
-        if (initSync.get()) {
-            return;
-        }
-        try {
-            RouteTable.getInstance().refreshLeader(RaftServerManager.getCliClientServiceInstance(), group, 1000);
-            PeerId peerId = RouteTable.getInstance().selectLeader(group);
-            if (peerId != null) {
-                syncCurrentNodeInfo(peerId);
+        if (initSync.compareAndSet(false, true)) {
+            try {
+                RouteTable.getInstance().refreshLeader(RaftServerManager.getCliClientServiceInstance(), group, 1000);
+                PeerId peerId = RouteTable.getInstance().selectLeader(group);
+                if (peerId != null) {
+                    syncCurrentNodeInfo(peerId);
+                }
+            } catch (Exception e) {
+                LOGGER.error(e.getMessage(), e);
             }
-        } catch (Exception e) {
-            LOGGER.error(e.getMessage(), e);
         }
     }
 
@@ -385,7 +399,7 @@ public class RaftStateMachine extends StateMachineAdapter {
         try {
             // Ensure that the current leader must be version 2.1 or later to synchronize the operation
             Node leader = raftClusterMetadata.getLeader();
-            if (leader != null && StringUtils.isNotBlank(leader.getVersion()) && initSync.compareAndSet(false, true)) {
+            if (leader != null && StringUtils.isNotBlank(leader.getVersion())) {
                 RaftServer raftServer = RaftServerManager.getRaftServer(group);
                 PeerId cureentPeerId = raftServer.getServerId();
                 Node node = raftClusterMetadata.createNode(XID.getIpAddress(), XID.getPort(), cureentPeerId.getPort(),
