@@ -57,7 +57,7 @@ public class DefaultCore implements Core {
     private static final int RETRY_XAER_NOTA_TIMEOUT = ConfigurationFactory.getInstance().getInt(XAER_NOTA_RETRY_TIMEOUT,
             DefaultValues.DEFAULT_XAER_NOTA_RETRY_TIMEOUT);
 
-    private static Map<BranchType, AbstractCore> coreMap = new ConcurrentHashMap<>();
+    private static final Map<BranchType, AbstractCore> CORE_MAP = new ConcurrentHashMap<>();
 
     private static final boolean PARALLEL_HANDLE_BRANCH =
             ConfigurationFactory.getInstance().getBoolean(ENABLE_PARALLEL_HANDLE_BRANCH_KEY, false);
@@ -72,7 +72,7 @@ public class DefaultCore implements Core {
             new Class[] {RemotingServer.class}, new Object[] {remotingServer});
         if (CollectionUtils.isNotEmpty(allCore)) {
             for (AbstractCore core : allCore) {
-                coreMap.put(core.getHandleBranchType(), core);
+                CORE_MAP.put(core.getHandleBranchType(), core);
             }
         }
     }
@@ -84,7 +84,7 @@ public class DefaultCore implements Core {
      * @return the core
      */
     public AbstractCore getCore(BranchType branchType) {
-        AbstractCore core = coreMap.get(branchType);
+        AbstractCore core = CORE_MAP.get(branchType);
         if (core == null) {
             throw new NotSupportYetException("unsupported type:" + branchType.name());
         }
@@ -98,7 +98,7 @@ public class DefaultCore implements Core {
      * @param core       the core
      */
     public void mockCore(BranchType branchType, AbstractCore core) {
-        coreMap.put(branchType, core);
+        CORE_MAP.put(branchType, core);
     }
 
     @Override
@@ -212,6 +212,14 @@ public class DefaultCore implements Core {
                     SessionHelper.removeBranch(globalSession, branchSession, !retrying);
                     return CONTINUE;
                 }
+                // Only databases with read-only optimization, such as Oracle,
+                // will report the RDONLY status during XA transactions.
+                // At this point, the branch transaction can be ignored.
+                if (currentStatus == BranchStatus.PhaseOne_RDONLY
+                        && branchSession.getBranchType() == BranchType.XA) {
+                    SessionHelper.removeBranch(globalSession, branchSession, !retrying);
+                    return CONTINUE;
+                }
                 try {
                     BranchStatus branchStatus = getCore(branchSession.getBranchType()).branchCommit(globalSession, branchSession);
                     if (isXaerNotaTimeout(globalSession,branchStatus)) {
